@@ -1,3 +1,7 @@
+c Note that calls to 'write' have been commented out  
+c since such call trigger warnings in R -KMM, March 2012 
+c Also, made DUMMY double precision DUMMY(*) 
+
 C     SUBROUTINE NNNPLS  (A,MDA,M,N,CON,B,X,RNORM,W,ZZ,INDEX,MODE)
 C   
 C  Algorithm NNNPLS: NONNEGATIVE LEAST SQUARES with trivial modifications 
@@ -61,8 +65,8 @@ c     double precision A(MDA,N), B(M), W(N), X(N), ZZ(M)
       integer INDEX(*)  
       integer C1, C2
       double precision CON(N)
-      double precision A(MDA,*), B(*), W(*), X(*), ZZ(*)   
-      double precision ALPHA, ASAVE, CC, DIFF, DUMMY, FACTOR, RNORM
+      double precision A(MDA,*), B(*), W(*), X(*), ZZ(*), DUMMY(1) 
+      double precision ALPHA, ASAVE, CC, DIFF, FACTOR, RNORM
       double precision SM, SS, T, TEMP, TWO, UNORM, UP, WMAX
       double precision ZERO, ZTEST
       parameter(FACTOR = 0.01d0)
@@ -89,7 +93,8 @@ C                    INITIALIZE THE ARRAYS INDEX() AND X().
 C   
           DO 20 I=1,N   
           X(I)=ZERO     
-   20     INDEX(I)=I    
+          INDEX(I)=I
+ 20       END DO
 C   
       IZ2=N 
       IZ1=1 
@@ -108,7 +113,8 @@ C
          J=INDEX(IZ)   
          SM=ZERO   
          DO 40 L=NPP1,M
-   40        SM=SM+A(L,J)*B(L)     
+            SM=SM+A(L,J)*B(L)
+ 40      END DO
          W(J)=SM   
    50 continue
 C                                   FIND LARGEST POSITIVE W(J). 
@@ -138,7 +144,8 @@ C
       UNORM=ZERO
       IF (NSETP .ne. 0) then
           DO 90 L=1,NSETP   
-   90       UNORM=UNORM+A(L,J)**2     
+             UNORM=UNORM+A(L,J)**2
+ 90       END DO
       endif
       UNORM=sqrt(UNORM) 
       IF (DIFF(UNORM+ABS(A(NPP1,J))*FACTOR,UNORM) .gt. ZERO) then
@@ -147,7 +154,8 @@ C        COL J IS SUFFICIENTLY INDEPENDENT.  COPY B INTO ZZ, UPDATE ZZ
 C        AND SOLVE FOR ZTEST ( = PROPOSED NEW VALUE FOR X(J) ).    
 C   
          DO 120 L=1,M  
-  120        ZZ(L)=B(L)    
+            ZZ(L)=B(L)
+ 120     END DO
          CALL H12 (2,NPP1,NPP1+1,M,A(1,J),1,UP,ZZ,1,1,1)   
          ZTEST=ZZ(NPP1)/A(NPP1,J)  
 C   
@@ -171,7 +179,8 @@ C     COL J,  SET W(J)=0.
 C   
   140 continue
       DO 150 L=1,M  
-  150    B(L)=ZZ(L)    
+         B(L)=ZZ(L)
+ 150  END DO 
 C   
       INDEX(IZ)=INDEX(IZ1)  
       INDEX(IZ1)=J  
@@ -188,7 +197,8 @@ C
 C   
       IF (NSETP .ne. M) then
          DO 180 L=NPP1,M   
-  180       A(L,J)=ZERO   
+            A(L,J)=ZERO
+ 180     END DO
       endif
 C   
       W(J)=ZERO 
@@ -206,7 +216,7 @@ C
       ITER=ITER+1   
       IF (ITER .gt. ITMAX) then
          MODE=3
-         write (*,'(/a)') ' NNLS quitting on iteration count.'
+c        write (*,'(/a)') ' NNLS quitting on iteration count.'
          GO TO 350 
       endif
 C   
@@ -290,7 +300,8 @@ C
 C         COPY B( ) INTO ZZ( ).  THEN SOLVE AGAIN AND LOOP BACK.
 C   
       DO 310 I=1,M  
-  310     ZZ(I)=B(I)    
+         ZZ(I)=B(I)
+ 310  END DO
       RTNKEY = 2
       GO TO 400 
   320 CONTINUE  
@@ -300,7 +311,8 @@ C
   330 continue
       DO 340 IP=1,NSETP 
           I=INDEX(IP)   
-  340     X(I)=ZZ(IP)   
+          X(I)=ZZ(IP)
+ 340   END DO
 C        ALL NEW COEFFS ARE POSITIVE.  LOOP BACK TO BEGINNING.  
       GO TO 30  
 C   
@@ -323,10 +335,12 @@ C  IS DESIRED
       SM=ZERO   
       IF (NPP1 .le. M) then
          DO 360 I=NPP1,M   
-  360       SM=SM+B(I)**2 
+            SM=SM+B(I)**2
+ 360     END DO
       else
          DO 380 J=1,N  
-  380       W(J)=ZERO     
+            W(J)=ZERO
+ 380     END DO
       endif
       RNORM=sqrt(SM)    
       RETURN
@@ -345,5 +359,14 @@ C
          JJ=INDEX(IP)  
          ZZ(IP)=ZZ(IP)/A(IP,JJ)    
   430 continue
-      go to (200, 320), RTNKEY
-      END  
+      select case(RTNKEY)
+      case(1)
+         GO TO 200
+      case(2)
+         GO TO 320
+      case default
+ 440     continue 
+      end select
+      END
+
+      
